# -*- coding: utf-8 -*-
import objectpack
from educommon import ioc
from educommon.utils import date


# шорткаты продуктовых моделей
Specialist = ioc.get('edureception__Specialist')
Office = ioc.get('edureception__Office')
Applicant = ioc.get('edureception__Applicant')


class BaseWeekDaysVirtModel(objectpack.VirtualModel):
    u"""
    Модель имитирует записи дней по неделям.

    (1-й понедельник, .., 5-й понедельник)
    """

    @staticmethod
    def postfix(day_idx):
        u"""
        Окончания для склонения номера недели по имени дня.
        :rtype: unicode
        """
        if day_idx == date.SUN_IDX:
            # Воскресенье: 2-е воскресенье
            postfix = u'e'
        elif day_idx in [date.WED_IDX, date.FRI_IDX, date.SAT_IDX]:
            # Среда, Пятница, Суббота: 3-я среда
            postfix = u'я'
        else:
            # Прочее: 4-й понедельник
            postfix = u'й'
        return postfix

    @classmethod
    def _get_ids(cls, day_idx):
        u"""
        Генератор дней (1-й понедельник, .., 5-й понедельник).

        :params int day_idx: номер дня недели
        """
        from .base import AbstractCrontab
        # имя дня недели по номеру дня недели
        day_name = dict(AbstractCrontab.WEEKDAYS)[day_idx].lower()
        return ((
            i, u'%s-%s %s' % (i, cls.postfix(day_idx), day_name)
        ) for i in xrange(1, AbstractCrontab.DEFAULT_WEEKS_COUNT + 1))

    def __init__(self, (_id, name)):
        self.id = _id
        self.name = name

    class _meta:
        verbose_name = u'Дни по номерам недель'
        verbose_name_plural = u'Дни по номерам недель'
