# -*- coding: utf-8 -*-
from m3_ext.ui import all_components as ext
from educommon.objectpack.ui import BaseGridWindow, GridPanel
from educommon.utils.ui import formed


class TimeTableGridPanel(GridPanel):

    u"""Панель с гридом."""

    @classmethod
    def configure_grid(cls, grid, params):
        grid = super(TimeTableGridPanel, cls).configure_grid(grid, params)
        grid.force_fit = True
        grid.template_globals = 'ui-js/specialist-reception-grid.js'

        read_only = params.get('read_only')

        if not read_only:
            grid.url_new = grid.url_edit = params['add_url']
            grid.url_delete = params['delete_url']

        return grid


class TimeTableWindow(BaseGridWindow):

    u"""Окно 'Расписания приема'."""

    grid_panel_cls = TimeTableGridPanel

    def _init_components(self):
        super(TimeTableWindow, self)._init_components()
        self.date_fld = ext.ExtDateField(
            name='date', label=u'Дата', allow_blank=False
        )
        self.date_fld._listeners['specialkey'] = 'dateSpecialKeyChange'
        self.specialist_fld = ext.ExtDictSelectField(
            name='specialist_id',
            label=u'Специалист',
            display_field='fullname',
            hide_clear_trigger=False,
        )

        self.close_btn = self.btn_close = ext.ExtButton(
            name='close_btn',
            text=u'Закрыть',
            handler='function(){Ext.getCmp("%s").close();}' % self.client_id
        )
        self.print_btn = ext.ExtButton(
            text=u'Печать', icon_cls='print-icon',
            handler='function(){printSchedule();}'
        )

        # исключения для make_read_only
        self._mro_exclude_list.extend([
            self.close_btn, self.print_btn
        ])

    def _do_layout(self):
        # добавление фильтрующих полей в фильтрующую панель
        self.filter_cnt.filters.extend([
            self.date_fld, self.specialist_fld,
        ])
        super(TimeTableWindow, self)._do_layout()
        self.buttons.extend([self.print_btn, self.btn_close])

        self.filter_cnt.items.extend([
            formed(self.date_fld, width=150, label_width=35),
            ext.ExtContainer(layout='fit', style={'padding': '5px'}),
            formed(self.specialist_fld, width=300, label_width=70),
        ])
        self.items.extend([self.filter_cnt, self.grid_panel])

    def set_params(self, params):
        super(TimeTableWindow, self).set_params(params)
        self.template_globals = 'ui-js/specialist-reception-timetable-win.js'
        self.date_fld.value = params['date']
        self.specialist_fld.pack = params['specialist_pack']
        self.print_url = params['print_url']

        if params.get('default_specialist'):
            self.specialist_fld.set_value_from_model(
                params.get('default_specialist'))
